summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/filesource.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/filesource.h')
-rw-r--r--kstars/kstars/filesource.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kstars/kstars/filesource.h b/kstars/kstars/filesource.h
index 39fb83bd..d9ab95d9 100644
--- a/kstars/kstars/filesource.h
+++ b/kstars/kstars/filesource.h
@@ -20,20 +20,20 @@
/**@class FileSource
*FileSource is an asynchronous class for reloading star data while running
*the program. It's basing on QDataSource class and implements the function
*for reading a file step by step and send these data to an QDataSink object.
*KStarsData uses this class for asynchronous io.
*@author Thomas Kabelmann
*@version 1.0
*/
-#include <qasyncio.h>
-#include <qstring.h>
+#include <tqasyncio.h>
+#include <tqstring.h>
class KStarsData;
class KSFileReader;
-class FileSource : public QDataSource {
+class FileSource : public TQDataSource {
public:
/**constructor needs an KStarsData object, a file name and the new magnitude
@@ -53,12 +53,12 @@ class FileSource : public QDataSource {
*/
bool rewindable() { return false; }
/**The function for sending data to an QDataSink object. Here will all data
*operations defined. Because this function is virtual, we need a second int
*parameter, but we don't use it, so it's unnamed.
*@p sink pointer to the QDataSink object which will receive the data stream
*/
- void sendTo( QDataSink *sink, int );
+ void sendTo( TQDataSink *sink, int );
/**@return current magnitude to load (always returns maxMagnitude)
*/
@@ -82,7 +82,7 @@ class FileSource : public QDataSource {
KStarsData *data;
/**maxLines defines how many lines in data file should be read and
*send to QDataSink. This is only needed if a data block is longer
*than the max defined lines. I figured out this value of 500
*on a fast system, so if it is to high the value might be decreased.
*A high value means faster reloading but perhaps on slow systems this
@@ -98,7 +98,7 @@ class FileSource : public QDataSource {
/**The loaded data will stored in a string array and a pointer to first
*object in array will send to StarDataSink.
*/
- QString stringArray[ maxLines ];
+ TQString stringArray[ maxLines ];
};
@@ -20,20 +20,20 @@
/**@class FileSource
*FileSource is an asynchronous class for reloading star data while running
- *the program. It's basing on QDataSource class and implements the function
- *for reading a file step by step and send these data to an QDataSink object.
+ *the program. It's basing on TQDataSource class and implements the function
+ *for reading a file step by step and send these data to an TQDataSink object.
*KStarsData uses this class for asynchronous io.
*@author Thomas Kabelmann
@@ -53,12 +53,12 @@ class FileSource : public QDataSource {
*/
bool rewindable() { return false; }
- /**The function for sending data to an QDataSink object. Here will all data
+ /**The function for sending data to an TQDataSink object. Here will all data
*operations defined. Because this function is virtual, we need a second int
*parameter, but we don't use it, so it's unnamed.
@@ -53,12 +53,12 @@ class FileSource : public QDataSource {
*operations defined. Because this function is virtual, we need a second int
*parameter, but we don't use it, so it's unnamed.
- *@p sink pointer to the QDataSink object which will receive the data stream
+ *@p sink pointer to the TQDataSink object which will receive the data stream
*/
@@ -82,7 +82,7 @@ class FileSource : public QDataSource {
KStarsData *data;
/**maxLines defines how many lines in data file should be read and
- *send to QDataSink. This is only needed if a data block is longer
+ *send to TQDataSink. This is only needed if a data block is longer
*than the max defined lines. I figured out this value of 500
*on a fast system, so if it is to high the value might be decreased.